==> ejc-equipment-api-3.0.0-20210401.093648-217-sources.jar: com/ejianc/business/equipment/hystrix/EquipmentContractHystrix.java <==
package com.ejianc.business.equipment.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.equipment.api.IEquipmentContractApi;
import com.ejianc.business.equipment.vo.EquipmentReportVo;
import com.ejianc.business.tax.pub.api.IPubInvoiceReceiveApi;
import com.ejianc.business.tax.vo.ContractResVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;

/**
 * 模块hystrix
 * 
 * @author guoming
 *
 */
@Component
public class EquipmentContractHystrix implements IEquipmentContractApi {

	@Override
	public CommonResponse<JSONObject> getContract(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getContractSettle(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getRentSettle(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updatePurchaseContractSumPayMny(Long contractId, BigDecimal payMny, BigDecimal prepayMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentContractSumPayMny(Long contractId, BigDecimal payMny, BigDecimal prepayMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updatePurchaseSettleSumPayMny(Long settleId, BigDecimal payMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentSettleSumPayMny(Long settleId, BigDecimal payMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updatePurchaseSettleSumApplyMny(Long settleId, BigDecimal applyMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentSettleSumApplyMny(Long settleId, BigDecimal applyMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> afterApproveInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny){
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> afterRevocationInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny){
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> rentAfterApproveInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> rentAfterRevocationInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<EquipmentReportVo>> getMonthEquipmentMny(Long projectId, Integer lastDay) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<ContractResVO> getContractById(Long contractId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
}

==> ejc-equipment-api-3.0.0-20221226.072730-414-sources.jar: com/ejianc/business/equipment/hystrix/EquipmentContractHystrix.java <==
package com.ejianc.business.equipment.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.equipment.api.IEquipmentContractApi;
import com.ejianc.business.equipment.vo.EquipmentReportVo;
import com.ejianc.business.equipment.vo.RentUseRecordVO;
import com.ejianc.business.tax.pub.api.IPubInvoiceReceiveApi;
import com.ejianc.business.tax.vo.ContractResVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;

/**
 * 模块hystrix
 * 
 * @author guoming
 *
 */
@Component
public class EquipmentContractHystrix implements IEquipmentContractApi {

	@Override
	public CommonResponse<JSONObject> getContract(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getContractSettle(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getRentSettle(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updatePurchaseContractSumPayMny(Long contractId, BigDecimal payMny, BigDecimal prepayMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentContractSumPayMny(Long contractId, BigDecimal payMny, BigDecimal prepayMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updatePurchaseSettleSumPayMny(Long settleId, BigDecimal payMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentSettleSumPayMny(Long settleId, BigDecimal payMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updatePurchaseSettleSumApplyMny(Long settleId, BigDecimal applyMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentSettleSumApplyMny(Long settleId, BigDecimal applyMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> afterApproveInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny){
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> afterRevocationInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny){
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> rentAfterApproveInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> rentAfterRevocationInvoiceReceive(Long contractId, BigDecimal invoiceMny, BigDecimal invoiceTaxMny) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<EquipmentReportVo>> getMonthEquipmentMny(Long projectId, Integer lastDay) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<EquipmentReportVo>> getEquipment(Long projectId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateRentUseRecordSporadicUseFlag(List<RentUseRecordVO> rentUseRecordVOS) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<ContractResVO> getContractById(Long contractId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
}
